@@ -5,7 +5,6 @@
 # overview of the functions defined in this file:
 #
 #   tf2yn(x)
-#   caterase(s)
 #   var1(x)
 #   var1.cols(X)
 #   dot(x,y)
@@ -41,13 +40,6 @@ tf2yn <- function (x) {
     return("no")
 }
 
-# ----------------------------------------------------------------------
-# Output the string using 'cat', then move the cursor back to the
-# beginning of the string so that subsequent output will overwrite
-# this string.
-caterase <- function (s)
-  cat(s,rep("\b",nchar(s)),sep = "")
-
 # ----------------------------------------------------------------------
 # Return the second moment of x about its mean.
 var1 <- function (x) {
@@ -132,7 +124,7 @@ diagsq <- function (X, a = NULL) {
   # Execute the C routine using the .Call interface. The main reason
   # for using .Call interface is that there is less of a constraint on
   # the size of the input matrices.
-  out <- .Call("diagsq_Call",X = X,a = a,y = y)
+  out <- .Call(C_diagsq_Call,X = X,a = a,y = y)
   return(y)
 }
 
@@ -159,7 +151,7 @@ diagsqt <- function (X, a = NULL) {
   # Execute the C routine using the .Call interface. The main reason
   # for using .Call interface is that there is less of a constraint on
   # the size of the input matrices.
-  out <- .Call("diagsqt_Call",X = X,a = a,y = y)
+  out <- .Call(C_diagsqt_Call,X = X,a = a,y = y)
   return(y)
 }
 
