@@ -70,7 +70,7 @@ varbvsbinupdate <- function (X, sa, logodds, stats, alpha0, mu0, Xr0, i) {
   # components that change are alpha, mu and Xr. Note that I need to
   # subtract 1 from the indices because R vectors start at 1, and C
   # arrays start at 0.
-  out <- .Call("varbvsbinupdate_Call",X = X,sa = as.double(sa),
+  out <- .Call(C_varbvsbinupdate_Call,X = X,sa = as.double(sa),
                logodds = as.double(logodds),d = as.double(stats$d),
                xdx = as.double(stats$xdx),xy = as.double(stats$xy),
                xd = as.double(stats$xd),alpha = alpha,mu = mu,Xr = Xr,
